@@ -4,10 +4,14 @@
 Usage:
     shelephant_dump [options] <file>...
 
+Argument(s):
+    Files to dump. By default the filenames are written relative to the output file.
+
 Options:
     -o, --output=N      Output YAML-file. [default: shelephant_dump.yaml]
+    -a, --append        Append existing file.
     -c, --command       Interpret the input as a command (instead of as filenames).
-    -a, --abspath       Store absolute paths (default: relative to the output file).
+        --abspath       Store absolute paths (default: relative to the output file).
     -s, --sort          Sort filenames.
     -f, --force         Overwrite output file without prompt.
     -h, --help          Show help.
@@ -21,7 +25,8 @@ import os
 import subprocess
 
 from .. import __version__
-from . import YamlDump
+from .. import YamlDump
+from .. import YamlRead
 
 
 def main():
@@ -43,6 +48,15 @@ def main():
     if args['--sort']:
         files = sorted(files)
 
+    if args['--append']:
+
+        main = YamlRead(args['--output'])
+        if type(main) != list:
+            Error('Can only append a "flat" file')
+
+        files = main + files
+        args['--force'] = True
+
     YamlDump(args['--output'], files, args['--force'])
 
 
